@@ -6,58 +6,6 @@ from featurebox.layer.graph.baselayer import BaseLayer
 
 
 class AtomLayer(BaseLayer):
-    """
-    Convolutional operation on graphs.
-
-    There are 3 length for first dim(axis) of preprocessing.
-
-    N_atom > N_ele> N_node.
-
-    1. N_node: This is consistent with the number of target. N_node==N_target.
-        In brief, The  first dim(axis) of preprocessing should be reduced to N_node to calculated error in the final network.
-        (Not is this Layer, but the total network).
-
-        N_node is the min preprocessing number. which can be expand in to N_atom, and N_ele.
-
-        Examples:
-            new_data = self.expand_idx(preprocessing, node_atom_idx)
-            new_data = self.expand_idx(preprocessing, node_ele_idx)
-
-    2. N_ele: This is the number of type of atomic number.
-
-        This type is not used very much.
-
-        N_node is the min preprocessing number. which can be expand in to and N_atom merged to N_node.
-
-        Examples:
-            new_data = self.expand_idx(preprocessing, ele_atom_idx)
-            new_data = self.merge_idx(preprocessing, node_ele_idx)
-
-    3. N_atom (N): This is the number of all atom in batch preprocessing.
-
-        The preprocessing with N could be merged in to N_node by node_atom_idx.
-
-        Examples:
-            new_data = self.merge_idx(preprocessing, node_atom_idx)
-            new_data = self.merge_idx(preprocessing, ele_atom_idx)
-
-    Common Preprocessing:
-        atom_fea:(torch.Tensor) torch.float32, shape (N, atom_fea_len)
-        nbr_fea:(torch.Tensor) torch.float32, shape (N, M, atom_fea_len) M default is 5.
-        state_fea: (torch.Tensor) torch.float32, shape (N_node, state_fea_len)
-        atom_nbr_idx: (torch.Tensor) torch.int64, shape (N, M) M default is 5.
-
-        oe: (torch.Tensor) torch.float32, shape (N, 17) in atom_fea
-        sgt: (torch.Tensor) torch.float32, shape (N_node, 6) in state_fea
-
-        node_atom_idx: (list of torch.Tensor) torch.int64, each one shape is different.
-        node_ele_idx: (list of torch.Tensor) torch.int64, each one shape is different.
-        ele_atom_idx: (list of torch.Tensor) torch.int64, each one shape is different.
-
-    Theoretically "oe" it should belong to atom_fea,
-    The reason for separation form atom_fea is better handling.
-    """
-
     def __init__(self, atom_fea_len, nbr_fea_len, state_fea_len=0):
         """
         Notes:
